@@ -90,17 +90,21 @@ class _VictorBase:
 
     error_to_catch = ()  # Exception
 
+    remove_other_hetatms = True #remove all protein heteroatoms that are not water or ligand when loaded from PDB
+
     # ================== Init ==========================================================================================
 
     def __init__(self,
                  hits: List[Chem.Mol],
-                 pdb_filename: str,
+                 pdb_filename: Union[None, str] = None,
+                 pdb_block: Union[None, str] = None,
                  ligand_resn: str = 'LIG',
                  ligand_resi: Union[int, str] = '1B',
                  covalent_resn: str = 'CYS',  # no other option is accepted.
                  covalent_resi: Optional[Union[int, str]] = None,
                  extra_protein_constraint: Union[str] = None,
                  pose_fx: Optional[Callable] = None,
+#                 remove_other_hetatms: bool = True,
                  ):
         """
         Initialise Victor in order to allow either combinations (merging/linking without a given aimed for molecule)
@@ -108,17 +112,24 @@ class _VictorBase:
 
         :param hits: list of rdkit molecules
         :param pdb_filename: file of apo structure
+        :param pdb_block: alternative for above: a string of apo structure
         :param ligand_resn: 3 letter code or your choice
         :param ligand_resi: Rosetta-style pose(int) or pdb(str)
         :param covalent_resn: only CYS accepted. if smiles has no * it is ignored
         :param covalent_resi: Rosetta-style pose(int) or pdb(str)
         :param extra_protein_constraint: multiline string of constraints relevant to the protein
         :param pose_fx: a function to call with pose to tweak or change something before minimising.
+
         """
         # ## Store
         # entry attributes
-        with open(pdb_filename) as fh:
-            self.apo_pdbblock = fh.read()
+        if pdb_filename:
+            with open(pdb_filename) as fh:
+                self.apo_pdbblock = fh.read()
+        elif pdb_block:
+            self.apo_pdbblock = pdb_block
+        else:
+            raise ValueError('Provide a pdb_filename or pdb_block of the template')
         self.hits = hits
         self.ligand_resn = ligand_resn.upper()
         self.ligand_resi = ligand_resi
@@ -160,6 +171,6 @@ class _VictorBase:
         self.error_msg = ''
 
     # ----------------- init called methods ----------------------------------------------------------------------------
-
-    def slugify(self, name: str):
+    @classmethod
+    def slugify(cls, name: str):
         return re.sub(r'[\W_.-]+', '-', name)
